@@ -3,7 +3,8 @@ from __future__ import with_statement
 import sys
 from nose import SkipTest
 from flask import Flask
-from flaskext.assets import Environment, ManageAssets
+from flask.ext.assets import Environment, ManageAssets
+from webassets.script import GenericArgparseImplementation
 
 try:
     from flaskext.script import Manager
@@ -21,28 +22,25 @@ class TestScript:
         # Setup the webassets.script with a mock main() function,
         # so we can check whether our call via Flask-Script actually
         # goes through.
-        def dummy_main(argv, *a, **kw):
-            self.last_script_call = argv
-            return 0
-        from webassets import script
-        old_main = script.main
-        script.main = dummy_main
+        test_inst = self
+        class DummyArgparseImplementation(GenericArgparseImplementation):
+            def run_with_argv(self, argv):
+                test_inst.last_script_call = argv
+                return 0
+
+        mgmt = Manager(self.app)
+        mgmt.add_command('assets',
+                ManageAssets(self.env, impl=DummyArgparseImplementation))
 
         try:
-            mgmt = Manager(self.app)
-            mgmt.add_command('assets', ManageAssets(self.env))
-
-            try:
-                # -h is a great test as that is something Flask-Script might
-                # want to claim for itself.
-                sys.argv = ['./manage.py', 'assets', '-h']
-                mgmt.run()
-            except SystemExit:
-                # Always raised, regardless of success or failure of command
-                pass
-            assert self.last_script_call == ['-h']
-        finally:
-            script.main = old_main
+            # -h is a great test as that is something Flask-Script might
+            # want to claim for itself.
+            sys.argv = ['./manage.py', 'assets', '-h']
+            mgmt.run()
+        except SystemExit:
+            # Always raised, regardless of success or failure of command
+            pass
+        assert self.last_script_call == ['-h']
 
     def test_call_auto_env(self):
         """Regression test: Passing the environment to the ManageAssets command
